
Changelog
=========

2020.06.01.dev1 (2020-05-17)
----------------------------

* First release on PyPI.

2020.09.01.dev1 (2020-09-01)
----------------------------

* Update documentation.
* Added docstrings and full apidocs.
* Fix for Backward Algorithm.
* Separate the toy AV simulator from the AST wrapper.
* Change AST environments to save the cloned sim state from pre-action, not post-action.
* Add travis deployment to PyPI.
* Removal of unsupported files.
* Expanded codecov to 90+%.
